Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1777)

Unified Diff: vm/flow_graph_builder.h

Issue 10700034: Add a goto instruction to the IL use it to terminate basic blocks. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/runtime/
Patch Set: Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | vm/flow_graph_builder.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: vm/flow_graph_builder.h
===================================================================
--- vm/flow_graph_builder.h (revision 9252)
+++ vm/flow_graph_builder.h (working copy)
@@ -114,9 +114,13 @@
// Append a graph fragment to this graph. Assumes this graph is open.
void Append(const EffectGraphVisitor& other_fragment);
// Append a single instruction. Assumes this graph is open.
void AddInstruction(Instruction* instruction);
+ // Append a new block entry to the graph.
+ void AddBlockEntry(BlockEntryInstr* successor);
+
// Append a 'diamond' branch and join to this graph, depending on which
// parts are reachable. Assumes this graph is open.
void Join(const TestGraphVisitor& test_fragment,
@@ -114,9 +114,13 @@
// Append a graph fragment to this graph. Assumes this graph is open.
void Append(const EffectGraphVisitor& other_fragment);
- // Append a single instruction. Assumes this graph is open.
+ // Append a single instruction. Assumes this graph is open. Can not be a
+ // block entry instruction.
void AddInstruction(Instruction* instruction);
« no previous file with comments | « no previous file | vm/flow_graph_builder.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698